A simple one-level platform game. Developed as part of ELEC2645 at University of Leeds, spring 2015.

Dependencies:   N5110 PinDetect PowerControl mbed

An ARM mbed LPC1768 microcontroller have been used to develop a handheld arcade game in the style of an old-school platformer. This project is entirely my own independent work in all stages of the development; including design, defining project specifications, breadboard prototyping, schematic and PCB layout using CAD, assembly, testing and software development. Due to this being part of the ELEC2645 Embedded Systems Project module at University of Leeds, spring 2015, limitations were given on the available hardware components. Credit is due to the authors of the dependent libraries (N5110, Pin Detect, PowerControl and mbed). I would also like to thank the author of Game Programming Patterns as well as the authors of SFML Game Development for providing me with useful sources for programming design patterns.

/media/uploads/Siriagus/game_assembled.jpg

Project aims

  • Implement simple gameplay:
    • A single, fixed (no scrolling) level.
    • Player can move left to right, jump and shoot.
    • Enemies will drop from the top of the screen.
    • The player gets points for shooting enemies.
    • The player dies when it gets hits by an enemy.
  • Implement a simple menu system.
  • Enable the user to adjust the brightness of the display.
  • Output sound to enhance the user experience.

Software

The program flow is controlled by a finite state machine. The implemented design was inspired by the State design pattern from the books Game Programming Patterns and SFML Game Development. The StateManager class is responsible for updating and rendering the current selected state. It also changes the state based on request from the current state. The framework built for the state machine used in this project makes it easy to add new screens. The different main states (indicated by the background colour) and how the user interaction is shown below: /media/uploads/Siriagus/arcadegameuserinteraction.png

Hardware

Schematic:

/media/uploads/Siriagus/schematic.png

Printed circuit board (PCB):

/media/uploads/Siriagus/pcb.png

Images

A seperate program was written to convert images (png) to text-representation of the maps. Enemies and numbers on the screen are also collected from a sprite-sheet created in the same manner.

/media/uploads/Siriagus/unileeds3.png /media/uploads/Siriagus/newmap2.png

Revision:
10:f2488a0ecab7
Parent:
0:1f92de30d43e
diff -r da608ae65df9 -r f2488a0ecab7 Joystick.h
--- a/Joystick.h	Sun May 03 11:48:42 2015 +0000
+++ b/Joystick.h	Fri May 08 14:39:36 2015 +0000
@@ -1,37 +1,47 @@
 /**
 @file Joystick.h
+@brief Class used for controlling the button
+@author Andreas Garmannslund
+@date April 2015
 */
 
 #ifndef JOYSTICK_H
 #define JOYSTICK_H
 
 #include "mbed.h"
+
+/** @brief Enum used for the 8-directions of the joystick. */
 enum JoystickDirection {CENTER, UP, DOWN, LEFT, RIGHT, UP_LEFT, UP_RIGHT, DOWN_LEFT, DOWN_RIGHT, UNKNOWN};
 
+/// Joystick class
 class Joystick
 {   
     public:
     
-        /** Creates a new Joystick object.
-        * @param x Pin connected to the horizontal potentiometer of the joystick.
-        * @param y Pin connected to the vertical potentiometer of the joystick.
+        /** Creates a new Joystick object
+        * @param x Pin connected to the horizontal potentiometer of the joystick
+        * @param y Pin connected to the vertical potentiometer of the joystick
         * @param button Pin connected to the button of the thumb joystick
         */
         Joystick(PinName x, PinName y, PinName button);
         
-        /** Destructor. Delete all allocated memory. **/
+        /** @brief Deconstructor. Frees allocated memory */
         ~Joystick();
         
-        /** Reads the current direction and button status of the joystick **/
-        void update(); // Updates the direction and button status of the joystick.
+        /** @brief Updates the current direction and button status of the joystick */
+        void update();
         
-        /** Calibrates the joystick. The joystick must be centered while this function is called. **/
-        void calibrate(); // Calibrates joystick by updating the center positions.
+        /** Calibrates the joystick. The joystick must be centered while this function is called */
+        void calibrate(); // Calibrates joystick by updating the center positions
         
-        /** Returns the current JoystickDirection based on last update. **/
+        /** Returns the current JoystickDirection based on last update
+        * @return The current JoystickDirection.
+        */
         int getDirection() {return dir;}
         
-        /** Reads the value of the button. **/
+        /** Reads the value of the button
+        * @return 1 if pressed, 0 otherwise
+        */
         int readButton() {return *btn;};
         
         /** Square set around the center of the joystick where the input is ignored. The axes are treated seperately. Can be varied from 0 (no dead-zone) to 0.5 (max value for dx and dy). **/